/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.model;

import com.vividsolutions.jts.geom.*;
import com.vividsolutions.jts.geom.impl.CoordinateArraySequence;
import java.io.Serializable;
import nl.cloudfarming.client.geoviewer.Geometrical;

/**
 *
 * @author Wytse Visser
 */
public class MachineGeographical implements Serializable, Geometrical<Point> {
    
    private Machine machine;
    
    public MachineGeographical(Machine machine) {
        this.machine = machine;
    }
    
    @Override
    public Point getCentroid() {
        Coordinate[] coordinates = new Coordinate[]{new Coordinate(machine.getLongitude(), machine.getLatitude())};
        CoordinateSequence coordSequence = new CoordinateArraySequence(coordinates);
        return new Point(coordSequence, new GeometryFactory());
    }
    
    @Override
    public String getTooltipText() {
        return machine.toString();
    }
    
    @Override
    public long getId() {
        return 1l;
    }
    
    @Override
    public Point getRenderObject(Envelope envelope) {
        return getCentroid();
    }

    @Override
    public Geometry getBoundingBox() {
        return null;
    }

    @Override
    public String getIconPath() {
        return "nl/cloudfarming/client/fleet/machine/bullet.png";
    }

    @Override
    public String getIconLabel() {
        return machine.getName();
    }

    @Override
    public Point getGeometry() {
        return getCentroid();
    }
}
