/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.model;

import java.util.Objects;
import org.openide.util.Lookup;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Wytse Visser
 */
public class Vehicle extends Machine {

    private transient Lookup lookup;
    
    public Vehicle() {
        this(null);
    }

    public Vehicle(String name) {
        super(name);
    }
    
    @Override
    public Lookup getLookup() {
        if(lookup == null) {
            lookup = Lookups.fixed(new VehicleGeographical());
        }
        return lookup;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Vehicle other = (Vehicle) obj;
        if (!Objects.equals(getName(), other.getName())) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        return hash;
    }

    private class VehicleGeographical extends MachineGeographical {

        public VehicleGeographical() {
            super(Vehicle.this);
        }

        @Override
        public String getIconPath() {
            return "nl/cloudfarming/client/fleet/vehicle/vehicle32.png";
        }
    }
}
